@@ -1,4 +1,4 @@
-// $Id: arraygeometry.hpp,v 1.1 2005/02/18 10:26:43 grosskur Exp $
+// $Id: arraygeometry.hpp,v 1.2 2005/02/25 12:22:16 grosskur Exp $
 //
 // Copyright (C) 2003 Alan Grosskurth
 //
@@ -30,9 +30,9 @@ struct ArrayGeometry {
 
     void load(std::istream& in);
 
-    lti::point size;
+    lti::ipoint size;
     lti::dpoint delta;
-    lti::point subgrid_size;
+    lti::ipoint subgrid_size;
     lti::dpoint subgrid_delta;
 };
 
