@@ -1,4 +1,4 @@
-// $Id: spotlist.hpp,v 1.2 2005/02/23 18:48:30 grosskur Exp $
+// $Id: spotlist.hpp,v 1.3 2005/02/25 12:22:16 grosskur Exp $
 //
 // Copyright (C) 2003 Alan Grosskurth
 //
@@ -28,15 +28,15 @@
 
 class Spot {
   public:
-    Spot(const lti::point& origin, const lti::imatrix& mask);
+    Spot(const lti::ipoint& origin, const lti::imatrix& mask);
 
-    const lti::point& origin() const;
+    const lti::ipoint& origin() const;
     const lti::imatrix& mask() const;
-    const lti::point size() const;
-    const lti::point center() const;
+    const lti::ipoint size() const;
+    const lti::ipoint center() const;
 
   private:
-    lti::point m_origin;
+    lti::ipoint m_origin;
     lti::imatrix m_mask;
 };
 
