@@ -1,4 +1,4 @@
-// $Id: spotter.hpp,v 1.1 2005/02/18 10:26:43 grosskur Exp $
+// $Id: spotter.hpp,v 1.2 2005/02/25 11:42:48 grosskur Exp $
 //
 // Copyright (C) 2003 Alan Grosskurth
 //
@@ -26,9 +26,9 @@
 #include <ltiImage.h>
 
 namespace spatter {
-    void spots_srg(const Grid& grid,
-                   const lti::image& image,
-                   SpotList& spot_list);
+    void spotlist_find(const Grid& grid,
+                       const lti::image& image,
+                       SpotList& spot_list);
 }
 
 #endif // INCLUDED_SPOTTER_HPP
